@@ -1,7 +1,7 @@
 /**********
 This library is free software; you can redistribute it and/or modify it under
 the terms of the GNU Lesser General Public License as published by the
-Free Software Foundation; either version 2.1 of the License, or (at your
+Free Software Foundation; either version 3 of the License, or (at your
 option) any later version. (See <http://www.gnu.org/copyleft/lesser.html>.)
 
 This library is distributed in the hope that it will be useful, but WITHOUT
@@ -14,8 +14,9 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2014 Live Networks, Inc.  All rights reserved.
-// A source that consists of multiple byte-stream files, read sequentially
+// Copyright (c) 1996-2018 Live Networks, Inc.  All rights reserved.
+// A source that consists of multiple byte-stream files, read sequentially.
+// (The input is an array of file names, with a terminating 'file name' of NULL.) 
 // Implementation
 
 #include "ByteStreamMultiFileSource.hh"
@@ -26,7 +27,7 @@ ByteStreamMultiFileSource
   : FramedSource(env),
     fPreferredFrameSize(preferredFrameSize), fPlayTimePerFrame(playTimePerFrame),
     fCurrentlyReadSourceNumber(0), fHaveStartedNewFile(False) {
-    // Begin by counting the number of sources:
+    // Begin by counting the number of sources (by looking for a terminating 'file name' of NULL):
     for (fNumSources = 0; ; ++fNumSources) {
       if (fileNameArray[fNumSources] == NULL) break;
     }
@@ -96,7 +97,7 @@ void ByteStreamMultiFileSource::doGetNextFrame() {
   } while (0);
 
   // An error occurred; consider ourselves closed:
-  handleClosure(this);
+  handleClosure();
 }
 
 void ByteStreamMultiFileSource
